<?php

declare(strict_types=1);

namespace Drupal\posthog_php\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Posthog settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'posthog_php_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['posthog_php.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('posthog_php.settings');

    $form['identify_users_on_login'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Identify users on login'),
      '#description' => $this->t('Enables identifying users on login, usind the users distinct id + the enabled user properties. Note, that if "Distinct ID" is set to "None", this setting will not have any effect.'),
      '#default_value' => $config->get('identify_users_on_login'),
    ];
    $form['process_person_profiles'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Process person profiles'),
      '#description' => $this->t('Whether to process person profiles
        Without this option enabled, posthog will NOT create person profiles and server-side events are anonymous by default. See <a href=:link1>Anonymous vs identified events</a> and
        <a href=:link2>Events</a> for more information. Anonymous users always send anonymous events.<br><strong>NOTE</strong>, that identified events can cost up to <strong>x4</strong> more than anonymous events!', [
          ':link1' => 'https://posthog.com/docs/data/anonymous-vs-identified-events',
          ':link2' => 'https://posthog.com/events',
        ]),
      '#default_value' => $config->get('process_person_profiles'),
    ];
    $form['enable_logging'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable logging'),
      '#default_value' => $config->get('enable_logging'),
      '#description' => $this->t('Enabling this option will log all failed Posthog PHP SDK calls to the Drupal log.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('posthog_php.settings')
      ->set('identify_users_on_login', $form_state->getValue('identify_users_on_login'))
      ->set('process_person_profiles', $form_state->getValue('process_person_profiles'))
      ->set('enable_logging', $form_state->getValue('enable_logging'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
